@@ -17,9 +17,11 @@ from .compat import basestring, is_py2
 class TimeConvert:
     def __init__(self, timezone=None, format=None):
         self.BASE_TIME_ZONE = tzlocal.get_localzone().zone
-        self.BASE_TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
+        self.DATETIME_FORMAT = '%Y-%m-%d %H:%M:%S'
+        self.DATE_FORMAT = '%Y-%m-%d'
+        self.WEEK_FORMAT = '%W'
         self.TIME_ZONE = timezone or self.BASE_TIME_ZONE
-        self.TIME_FORMAT = format or self.BASE_TIME_FORMAT
+        self.TIME_FORMAT = format or self.DATETIME_FORMAT
         self.SECOND_MILLISECOND = 10 ** 3
         self.SECOND_MICROSECOND = 10 ** 6
 
@@ -136,6 +138,7 @@ class TimeConvert:
         return utc_dt.astimezone(local_tz)
 
     # DATE
+
     def utc_date(self, dt=None, utc=True, ms=True, timezone=None, years=0, months=0, days=0, seconds=0, microseconds=0, milliseconds=0, minutes=0, hours=0, weeks=0):
         return self.datetime_to_date(self.utc_datetime(dt=dt, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks))
 
@@ -146,7 +149,7 @@ class TimeConvert:
         return datetime.datetime.date(dt)
 
     def is_the_same_day(self, dt1, dt2):
-        return self.local_string(dt1, format='%Y-%m-%d') == self.local_string(dt2, format='%Y-%m-%d')
+        return self.local_string(dt1, format=self.DATE_FORMAT) == self.local_string(dt2, format=self.DATE_FORMAT)
 
     # DATETIME
 
@@ -237,6 +240,24 @@ class TimeConvert:
         final_dt = self.to_local_datetime(dt=utc_dt) if not final_dt and utc_dt else final_dt
         return self.datetime_to_string(self.local_datetime(dt=final_dt, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks), self.format(format), isuc=isuc)
 
+    def utc_datetime_string(self, dt=None, utc=True, ms=True, timezone=None, years=0, months=0, days=0, seconds=0, microseconds=0, milliseconds=0, minutes=0, hours=0, weeks=0, local_dt=None, utc_dt=None, isuc=False):
+        return self.utc_string(dt=dt, format=self.DATETIME_FORMAT, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks, local_dt=local_dt, utc_dt=utc_dt, isuc=isuc)
+
+    def local_datetime_string(self, dt=None, utc=False, ms=True, timezone=None, years=0, months=0, days=0, seconds=0, microseconds=0, milliseconds=0, minutes=0, hours=0, weeks=0, local_dt=None, utc_dt=None, isuc=False):
+        return self.local_string(dt=dt, format=self.DATETIME_FORMAT, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks, local_dt=local_dt, utc_dt=utc_dt, isuc=isuc)
+
+    def utc_date_string(self, dt=None, utc=True, ms=True, timezone=None, years=0, months=0, days=0, seconds=0, microseconds=0, milliseconds=0, minutes=0, hours=0, weeks=0, local_dt=None, utc_dt=None, isuc=False):
+        return self.utc_string(dt=dt, format=self.DATE_FORMAT, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks, local_dt=local_dt, utc_dt=utc_dt, isuc=isuc)
+
+    def local_date_string(self, dt=None, utc=False, ms=True, timezone=None, years=0, months=0, days=0, seconds=0, microseconds=0, milliseconds=0, minutes=0, hours=0, weeks=0, local_dt=None, utc_dt=None, isuc=False):
+        return self.local_string(dt=dt, format=self.DATE_FORMAT, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks, local_dt=local_dt, utc_dt=utc_dt, isuc=isuc)
+
+    def utc_week_string(self, dt=None, utc=True, ms=True, timezone=None, years=0, months=0, days=0, seconds=0, microseconds=0, milliseconds=0, minutes=0, hours=0, weeks=0, local_dt=None, utc_dt=None, isuc=False):
+        return self.utc_string(dt=dt, format=self.WEEK_FORMAT, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks, local_dt=local_dt, utc_dt=utc_dt, isuc=isuc)
+
+    def local_week_string(self, dt=None, utc=False, ms=True, timezone=None, years=0, months=0, days=0, seconds=0, microseconds=0, milliseconds=0, minutes=0, hours=0, weeks=0, local_dt=None, utc_dt=None, isuc=False):
+        return self.local_string(dt=dt, format=self.WEEK_FORMAT, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks, local_dt=local_dt, utc_dt=utc_dt, isuc=isuc)
+
     # TIMESTAMP
 
     def __micro_or_milli(self, s, micro=False, milli=False):
@@ -320,6 +341,31 @@ class TimeConvert:
             return None
         return self.datetime_to_timestamp(self.string_to_local_datetime(string, format), ms=ms)
 
+    # TIMESTAMP ==> DATETIME
+
+    # local_stamp => utc_datetime - fromtimestamp + to_utc_datetime / utcfromtimestamp
+    # local_stamp => local_datetime - fromtimestamp
+    # utc_stamp => utc_datetime - fromtimestamp
+    # utc_stamp => local_datetime - fromtimestamp + to_local_datetime
+    def timestamp_to_datetime(self, stamp):
+        return datetime.datetime.fromtimestamp(stamp)
+
+    def timestamp_to_utc_datetime(self, stamp):
+        # return datetime.datetime.utcfromtimestamp(stamp)
+        return self.to_utc_datetime(self.timestamp_to_datetime(stamp))
+
+    def timestamp_to_local_datetime(self, stamp):
+        return self.timestamp_to_datetime(stamp)
+
+    def utc_timestamp_to_utc_datetime(self, stamp):
+        # return self.make_aware(self.timestamp_to_datetime(stamp), timezone='UTC')
+        return self.make_aware(self.timestamp_to_datetime(stamp), timezone=self.timezone('UTC'))
+
+    def utc_timestamp_to_local_datetime(self, stamp):
+        return self.to_local_datetime(self.timestamp_to_datetime(stamp))
+
+    # TIMESTAMP ==> AGE
+
     # TIME_DELTA
 
     def timestamp_delta(self, stamp1, stamp2, interval=None):
@@ -356,7 +402,7 @@ class TimeConvert:
     # TIME_COUNT_DOWN
 
     def timestamp_countdown(self, stamp, utc=True):
-        return abs(min((self.utc_timestamp() if utc else self.local_timestamp() - stamp), 0))
+        return abs(min(((self.utc_timestamp() if utc else self.local_timestamp()) - stamp), 0))
 
     def datetime_countdown(self, dt, utc=True):
         return self.timestamp_countdown(self.datetime_to_timestamp(dt), utc=utc)
@@ -482,6 +528,7 @@ class TimeConvert:
         return None
 
     # YEAR/MONTH/DAY
+
     def year(self, dt=None, utc=False, timezone=None, idx=0):
         return self.__datetime(dt=self.several_time_coming(dt=dt, utc=utc, timezone=timezone, years=idx), utc=utc).year
 
